@@ -1,9 +1,6 @@
 import logging
 from django.apps import AppConfig
 from django.utils.translation import gettext_lazy as _
-from django.apps import apps
-from django.conf import settings
-
 
 logger = logging.getLogger(__name__)
 
